==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/GROUPWOSTATUSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GROUPWOSTATUSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GROUPWOSTATUSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROUPWOSTATUSCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GROUPWOSTATUSID_Type", propOrder = {
    "groupwostatuscode",
    "description"
})
public class GROUPWOSTATUSID_Type {

    @XmlElement(name = "GROUPWOSTATUSCODE", required = true)
    protected String groupwostatuscode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété groupwostatuscode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGROUPWOSTATUSCODE() {
        return groupwostatuscode;
    }

    /**
     * Définit la valeur de la propriété groupwostatuscode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGROUPWOSTATUSCODE(String value) {
        this.groupwostatuscode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/GROUPWOSTATUSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GROUPWOSTATUSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GROUPWOSTATUSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROUPWOSTATUSCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GROUPWOSTATUSID_Type", propOrder = {
    "groupwostatuscode",
    "description"
})
public class GROUPWOSTATUSID_Type {

    @XmlElement(name = "GROUPWOSTATUSCODE", required = true)
    protected String groupwostatuscode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the groupwostatuscode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGROUPWOSTATUSCODE() {
        return groupwostatuscode;
    }

    /**
     * Sets the value of the groupwostatuscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGROUPWOSTATUSCODE(String value) {
        this.groupwostatuscode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
